@@ -1,7 +1,7 @@
 package Module::FatPack;
 
-our $DATE = '2016-12-27'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -175,7 +175,8 @@ sub fatpack_modules {
     if ($add_begin_block) {
         push @res, 'BEGIN {', "\n";
     } else {
-        push @res, "# BEGIN FATPACK CODE\n{\n";
+        push @res, "# BEGIN FATPACK CODE: ".join(" ", sort keys %fatpack_keys)."\n";
+        push @res, "{\n";
     }
     push @res, <<'_' if $args{assume_strict} // 1;
     no strict 'refs';
@@ -239,7 +240,8 @@ _
     unshift @INC, $hook unless grep {ref($_) && "$_" eq "$hook"} @INC;
 _
     }
-    push @res, "} # END OF FATPACK CODE\n\n";
+    push @res, "}\n";
+    push @res, "# END OF FATPACK CODE\n\n";
     push @res, $args{postamble} if defined $args{postamble};
 
     if ($args{output}) {
@@ -273,7 +275,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.13 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-12-27.
+This document describes version 0.14 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-12-28.
 
 =head1 FUNCTIONS
 
